#-- 
#  Copyright (C) 2008 Red Hat Inc.
#  
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2.1 of the License, or (at your option) any later version.
#  
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#  
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
#
# Author: Bryan Kearney <bkearney@redhat.com>
#--

$HOSTS_FILE = "/etc/hosts"
$NETWORK_FILE = "/etc/sysconfig/network"
$INTERFACE_FILE = "/etc/sysconfig/network-scripts/ifcfg-eth0"
$ACE_INFO_FILE = "/etc/sysconfig/ace/appliance_info.ini"

import "augeas"

class appliance_base {
		
	file_replacement{"mac_address" :
					    file => $INTERFACE_FILE,
						pattern => "^HWADDR=.*/",
						replacement => "HWADDR=${macaddress}",
						notify => Service[network]
	}
                    
	service {"network" :
		ensure => running,
		enable => true,
		hasstatus => false
	}
	
	service {"acpid" :
		ensure => "running",
		enable => "true",
		hasstatus => "true",		
	}	
}

define appliance_base::setup ($hostname = "") 
{
	include appliance_base
	
	file {"/etc/sysconfig/ace":
			ensure => "directory"
	}
	
	file {$ACE_INFO_FILE:
	    ensure => present,
    }
	
	augeas{"appliance_info":
	    context => "/files$ACE_INFO_FILE",
	    changes => [
	        "set appliance_version \"$appliance_version\"",
            "set appliance_name \"$appliance_name\""
        ],
        load_path => "${ace_home}lenses",
	    require => File[$ACE_INFO_FILE]
    }
    
	augeas{"appliance_install":
	    context => "/files$ACE_INFO_FILE",
	    changes => "set install_time \"$current_time\"",
        load_path => "${ace_home}lenses",
        onlyif => "match install_time size == 0",
	    require => File[$ACE_INFO_FILE]
    }    
	
	file_replacement{"appliance_hostname" :  
						file => $NETWORK_FILE,
						pattern => "^HOSTNAME=.*",
						replacement => "HOSTNAME=$hostname",
						notify => Service[network]						
	}	
	
}

