#-- 
#  Copyright (C) 2008 Red Hat Inc.
#  
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2.1 of the License, or (at your option) any later version.
#  
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#  
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
#
# Author: Bryan Kearney <bkearney@redhat.com>
#--

Puppet::Type.newtype(:file_replacement) do
	@doc = "Replaces a line in a file"
	
	newparam (:name) do
		desc "My Name"
	end
	
	newparam(:file) do
		desc "The file to replace"
	end
	
	newparam(:pattern) do
		desc "The pattern to replace"	
		
		munge do |value|
			return Regexp.new(value)
		end
	end
	
	newparam(:replacement) do
		desc "The substitution to make"
	end
	
	newproperty(:ensure) do
		desc "Whether the resource is in sync or not."
	
		defaultto :insync
		
		# Make output a bit prettier
		def change_to_s(currentvalue, newvalue)
			return "executed successfully"
		end		
		
		def retrieve
			if !(File.exist?(resource[:file]))
				return :outofsync
			else      		 		
			  data = File.read(resource[:file])	
			  return (data =~ resource[:pattern]).nil? ? :insync : :outofsync
			end
		end	
		
      newvalue :outofsync
      newvalue :insync do
			if !(File.exist?(resource[:file]))
				fail("File #{resource[:file]} does not exist")
			else         
				data = File.read(resource[:file])	
				newData = data.sub(resource[:pattern], resource[:replacement])
				file = File.new(resource[:file], "w+")
				file << newData
				file.close
				notice ("Inserted #{resource[:replacement]} into #{resource[:file]} using pattern #{resource[:pattern].source}") 
			end
      end		
      
	end
	
 	autorequire :file do
		[self[:file]]
	end	
    
end
